# Westworld
![](docs/docs/img/cover_hq_westworld1.jpg)

# Description
**Westworld** is a multi-agent simulation library, its goal to simulate and optimize systems and environments with multiple agents interacting. Its inspiration is drawn from Unity software and [Unity ML Agents](https://github.com/Unity-Technologies/ml-agents), adapted in Python. 

The goal is to be able to simulate environments in logistics, retails, epidemiology, providing pre-coded spatial environments and communication between agents. Optimization can be included using heuristics as well as Reinforcement Learning.

*Library under active development*

*The name is of course inspired by the TV series Westworld, which is actually a gigantic multi-agent simulation system.*

# Documentation
Documentation is available locally in docs folder or online at https://theolvs.github.io/westworld


# Repo structure

```
- docs : documentation of the library
- examples : simulation examples and development tests
- westworld : library
```